complete -c topgrade -s r -l run-type -d 'Pick between just running commands, running and logging commands, and just logging commands' -r -f -a "dry\t'Executing commands will just print the command with its argument'
wet\t'Executing commands will perform actual execution'
damp\t'Executing commands will print the command and perform actual execution'"
complete -c topgrade -l auto-retry -d 'Automatically retry failed steps up to COUNT times' -r
complete -c topgrade -l disable -d 'Do not perform upgrades for the given steps' -r -f -a "am\t''
android_studio\t''
antigravity\t''
app_man\t''
aqua\t''
asdf\t''
atom\t''
atuin\t''
audit\t''
auto_cpufreq\t''
bin\t''
bob\t''
brew_cask\t''
brew_formula\t''
bun\t''
bun_packages\t''
cargo\t''
certbot\t''
chezmoi\t''
chocolatey\t''
choosenim\t''
cinnamon_spices\t''
clam_av_db\t''
claude_code\t''
colima\t''
composer\t''
conda\t''
config_update\t''
containers\t''
cursor\t''
custom_commands\t''
deb_get\t''
deno\t''
distrobox\t''
dkp_pacman\t''
dotnet\t''
elan\t''
emacs\t''
falconf\t''
firmware\t''
flatpak\t''
flutter\t''
fossil\t''
gcloud\t''
gearlever\t''
gem\t''
getnf\t''
ghcup\t''
git_repos\t''
github_cli_extensions\t''
gnome_shell_extensions\t''
go\t''
guix\t''
haxelib\t''
helix\t''
helix_db\t''
helm\t''
home_manager\t''
hyprpm\t''
install_release\t''
jetbrains_aqua\t''
jetbrains_clion\t''
jetbrains_datagrip\t''
jetbrains_dataspell\t''
jetbrains_gateway\t''
jetbrains_goland\t''
jetbrains_idea\t''
jetbrains_mps\t''
jetbrains_phpstorm\t''
jetbrains_pycharm\t''
jetbrains_rider\t''
jetbrains_rubymine\t''
jetbrains_rustrover\t''
jetbrains_toolbox\t''
jetbrains_webstorm\t''
jetpack\t''
julia\t''
juliaup\t''
kakoune\t''
krew\t''
lensfun\t''
lure\t''
macports\t''
mamba\t''
mandb\t''
mas\t''
maza\t''
micro\t''
microsoft_office\t''
microsoft_store\t''
miktex\t''
mise\t''
myrepos\t''
nix\t''
nix_helper\t''
node\t''
ollama\t''
opam\t''
pacdef\t''
pacstall\t''
pearl\t''
pi\t''
pip3\t''
pip_review\t''
pip_review_local\t''
pipupgrade\t''
pipx\t''
pipxu\t''
pixi\t''
pkg\t''
pkgfile\t''
pkgin\t''
platformio_core\t''
pnpm\t''
poetry\t''
powershell\t''
protonplus\t''
protonup\t''
pyenv\t''
raco\t''
rcm\t''
remotes\t''
restarts\t''
rtcl\t''
ruby_gems\t''
rustup\t''
rye\t''
scoop\t''
sdkman\t''
self_update\t''
sheldon\t''
shell\t''
skills\t''
snap\t''
sparkle\t''
spicetify\t''
stack\t''
stew\t''
system\t''
tldr\t''
tlmgr\t''
tmux\t''
toolbx\t''
tpack\t''
typst\t''
uv\t''
vagrant\t''
vcpkg\t''
vim\t''
vite_plus\t''
volta_packages\t''
vscode\t''
vscode_insiders\t''
vscodium\t''
vscodium_insiders\t''
waydroid\t''
windsurf\t''
winget\t''
wsl\t''
wsl_update\t''
xcodes\t''
yadm\t''
yarn\t''
yazi\t''
zigup\t''
zvm\t''"
complete -c topgrade -l only -d 'Perform only the specified steps' -r -f -a "am\t''
android_studio\t''
antigravity\t''
app_man\t''
aqua\t''
asdf\t''
atom\t''
atuin\t''
audit\t''
auto_cpufreq\t''
bin\t''
bob\t''
brew_cask\t''
brew_formula\t''
bun\t''
bun_packages\t''
cargo\t''
certbot\t''
chezmoi\t''
chocolatey\t''
choosenim\t''
cinnamon_spices\t''
clam_av_db\t''
claude_code\t''
colima\t''
composer\t''
conda\t''
config_update\t''
containers\t''
cursor\t''
custom_commands\t''
deb_get\t''
deno\t''
distrobox\t''
dkp_pacman\t''
dotnet\t''
elan\t''
emacs\t''
falconf\t''
firmware\t''
flatpak\t''
flutter\t''
fossil\t''
gcloud\t''
gearlever\t''
gem\t''
getnf\t''
ghcup\t''
git_repos\t''
github_cli_extensions\t''
gnome_shell_extensions\t''
go\t''
guix\t''
haxelib\t''
helix\t''
helix_db\t''
helm\t''
home_manager\t''
hyprpm\t''
install_release\t''
jetbrains_aqua\t''
jetbrains_clion\t''
jetbrains_datagrip\t''
jetbrains_dataspell\t''
jetbrains_gateway\t''
jetbrains_goland\t''
jetbrains_idea\t''
jetbrains_mps\t''
jetbrains_phpstorm\t''
jetbrains_pycharm\t''
jetbrains_rider\t''
jetbrains_rubymine\t''
jetbrains_rustrover\t''
jetbrains_toolbox\t''
jetbrains_webstorm\t''
jetpack\t''
julia\t''
juliaup\t''
kakoune\t''
krew\t''
lensfun\t''
lure\t''
macports\t''
mamba\t''
mandb\t''
mas\t''
maza\t''
micro\t''
microsoft_office\t''
microsoft_store\t''
miktex\t''
mise\t''
myrepos\t''
nix\t''
nix_helper\t''
node\t''
ollama\t''
opam\t''
pacdef\t''
pacstall\t''
pearl\t''
pi\t''
pip3\t''
pip_review\t''
pip_review_local\t''
pipupgrade\t''
pipx\t''
pipxu\t''
pixi\t''
pkg\t''
pkgfile\t''
pkgin\t''
platformio_core\t''
pnpm\t''
poetry\t''
powershell\t''
protonplus\t''
protonup\t''
pyenv\t''
raco\t''
rcm\t''
remotes\t''
restarts\t''
rtcl\t''
ruby_gems\t''
rustup\t''
rye\t''
scoop\t''
sdkman\t''
self_update\t''
sheldon\t''
shell\t''
skills\t''
snap\t''
sparkle\t''
spicetify\t''
stack\t''
stew\t''
system\t''
tldr\t''
tlmgr\t''
tmux\t''
toolbx\t''
tpack\t''
typst\t''
uv\t''
vagrant\t''
vcpkg\t''
vim\t''
vite_plus\t''
volta_packages\t''
vscode\t''
vscode_insiders\t''
vscodium\t''
vscodium_insiders\t''
waydroid\t''
windsurf\t''
winget\t''
wsl\t''
wsl_update\t''
xcodes\t''
yadm\t''
yarn\t''
yazi\t''
zigup\t''
zvm\t''"
complete -c topgrade -l custom-commands -d 'Run only specific custom commands' -r
complete -c topgrade -l env -d 'Set environment variables' -r
complete -c topgrade -l notify-end -d 'When to send a notification at the end of a run' -r -f -a "always\t'Always send a notification (default)'
never\t'Never send a notification'
on_failure\t'Only send a notification if there were failures'"
complete -c topgrade -s y -l yes -d 'Say yes to package manager\'s prompt' -r -f -a "am\t''
android_studio\t''
antigravity\t''
app_man\t''
aqua\t''
asdf\t''
atom\t''
atuin\t''
audit\t''
auto_cpufreq\t''
bin\t''
bob\t''
brew_cask\t''
brew_formula\t''
bun\t''
bun_packages\t''
cargo\t''
certbot\t''
chezmoi\t''
chocolatey\t''
choosenim\t''
cinnamon_spices\t''
clam_av_db\t''
claude_code\t''
colima\t''
composer\t''
conda\t''
config_update\t''
containers\t''
cursor\t''
custom_commands\t''
deb_get\t''
deno\t''
distrobox\t''
dkp_pacman\t''
dotnet\t''
elan\t''
emacs\t''
falconf\t''
firmware\t''
flatpak\t''
flutter\t''
fossil\t''
gcloud\t''
gearlever\t''
gem\t''
getnf\t''
ghcup\t''
git_repos\t''
github_cli_extensions\t''
gnome_shell_extensions\t''
go\t''
guix\t''
haxelib\t''
helix\t''
helix_db\t''
helm\t''
home_manager\t''
hyprpm\t''
install_release\t''
jetbrains_aqua\t''
jetbrains_clion\t''
jetbrains_datagrip\t''
jetbrains_dataspell\t''
jetbrains_gateway\t''
jetbrains_goland\t''
jetbrains_idea\t''
jetbrains_mps\t''
jetbrains_phpstorm\t''
jetbrains_pycharm\t''
jetbrains_rider\t''
jetbrains_rubymine\t''
jetbrains_rustrover\t''
jetbrains_toolbox\t''
jetbrains_webstorm\t''
jetpack\t''
julia\t''
juliaup\t''
kakoune\t''
krew\t''
lensfun\t''
lure\t''
macports\t''
mamba\t''
mandb\t''
mas\t''
maza\t''
micro\t''
microsoft_office\t''
microsoft_store\t''
miktex\t''
mise\t''
myrepos\t''
nix\t''
nix_helper\t''
node\t''
ollama\t''
opam\t''
pacdef\t''
pacstall\t''
pearl\t''
pi\t''
pip3\t''
pip_review\t''
pip_review_local\t''
pipupgrade\t''
pipx\t''
pipxu\t''
pixi\t''
pkg\t''
pkgfile\t''
pkgin\t''
platformio_core\t''
pnpm\t''
poetry\t''
powershell\t''
protonplus\t''
protonup\t''
pyenv\t''
raco\t''
rcm\t''
remotes\t''
restarts\t''
rtcl\t''
ruby_gems\t''
rustup\t''
rye\t''
scoop\t''
sdkman\t''
self_update\t''
sheldon\t''
shell\t''
skills\t''
snap\t''
sparkle\t''
spicetify\t''
stack\t''
stew\t''
system\t''
tldr\t''
tlmgr\t''
tmux\t''
toolbx\t''
tpack\t''
typst\t''
uv\t''
vagrant\t''
vcpkg\t''
vim\t''
vite_plus\t''
volta_packages\t''
vscode\t''
vscode_insiders\t''
vscodium\t''
vscodium_insiders\t''
waydroid\t''
windsurf\t''
winget\t''
wsl\t''
wsl_update\t''
xcodes\t''
yadm\t''
yarn\t''
yazi\t''
zigup\t''
zvm\t''"
complete -c topgrade -l config -d 'Alternative configuration file' -r -F
complete -c topgrade -l remote-host-limit -d 'A regular expression for restricting remote host execution' -r
complete -c topgrade -l sudoloop-interval -d 'Interval in seconds between `sudo -v` invocations when --sudoloop is active (default: 240)' -r
complete -c topgrade -l log-filter -d 'Tracing filter directives' -r
complete -c topgrade -l gen-completion -d 'Print completion script for the given shell and exit' -r -f -a "bash\t''
elvish\t''
fish\t''
powershell\t''
zsh\t''"
complete -c topgrade -l edit-config -d 'Edit the configuration file'
complete -c topgrade -l config-reference -d 'Show config reference'
complete -c topgrade -s t -l tmux -d 'Run inside tmux'
complete -c topgrade -l no-tmux -d 'Don\'t run inside tmux'
complete -c topgrade -s c -l cleanup -d 'Cleanup temporary or old files'
complete -c topgrade -s n -l dry-run -d 'Print what would be done'
complete -c topgrade -l no-retry -d 'Do not ask to retry failed steps (same as --no-ask-retry, kept for legacy compatibility)'
complete -c topgrade -l no-ask-retry -d 'Do not ask what to do after a step fails'
complete -c topgrade -s v -l verbose -d 'Output debug logs. Alias for `--log-filter debug`'
complete -c topgrade -s k -l keep -d 'Prompt for a key before exiting'
complete -c topgrade -l skip-notify -d 'Skip sending a notification at the end of a run (deprecated: use --notify-end never)'
complete -c topgrade -l disable-predefined-git-repos -d 'Don\'t pull the predefined git repos'
complete -c topgrade -l show-skipped -d 'Show the reason for skipped steps'
complete -c topgrade -l allow-root -d 'Suppress warning and confirmation prompt if running as root'
complete -c topgrade -l sudoloop -d 'Periodically run `sudo -v` to avoid password re-prompts during updates'
complete -c topgrade -l gen-manpage -d 'Print roff manpage and exit'
complete -c topgrade -l no-self-update -d 'Don\'t update Topgrade'
complete -c topgrade -s h -l help -d 'Print help (see more with \'--help\')'
complete -c topgrade -s V -l version -d 'Print version'
